/**********************************************************************
Copyright (c) 2010 Alexander Kerner. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 ***********************************************************************/

package net.sf.mvc.prototype;

import net.sf.mvc.prototype.controller.InputController;
import net.sf.mvc.prototype.controller.InputOutputController;
import net.sf.mvc.prototype.controller.OutputController;
import net.sf.mvc.prototype.model.Model;
import net.sf.mvc.prototype.view.InputView;
import net.sf.mvc.prototype.view.InputOutputView;
import net.sf.mvc.prototype.view.OutputView;

/**
 * 
 * Helper class to init a MVC application properly.
 *
 * @author <a href="mailto:alex.kerner.24@googlemail.com">Alexander Kerner</a>
 * @version 2010-10-31
 *
 */
public class MVC {

	private MVC() {
		// singleton
	}

	/**
	 * 
	 * 
	 * Helper method to init a MVC application properly.
	 *
	 * @param <M> type of {@link Model}
	 * @param <V> type of {@link InputView}
	 * @param <W> type of {@link OutputView}
	 * @param <C> type of {@link InputController}
	 * @param <D> type of {@link OutputController}
	 * @param model {@link Model} to init
	 * @param viewIn {@link InputView} to init
	 * @param viewOut {@link OutputView} to init
	 * @param controllerIn {@link InputController} to init
	 * @param controllerOut {@link OutputController} to init
	 */
	public static <M extends Model<D>, V extends InputView<C>, W extends OutputView, C extends InputController<M>, D extends OutputController<W>> void init(
			M model, V viewIn, W viewOut, C controllerIn, D controllerOut) {
		controllerIn.addModel(model);
		controllerOut.addViewOut(viewOut);
		viewIn.addControllerIn(controllerIn);
		model.addControllerOut(controllerOut);
	}

	@Deprecated
	public static <M extends Model<D>, V extends InputView<C>, W extends OutputView, C extends InputController<M>, D extends OutputController<W>, E extends InputOutputController<M,W>, X extends InputOutputView<C>> void init(
			M model, X view, E controller) {
		// TODO fixme
		//init(model, view, view, controller, controller);
	}

}
