/**********************************************************************
Copyright (c) 2010 Alexander Kerner. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 ***********************************************************************/

package net.sf.mvc.prototype.controller;

import net.sf.mvc.prototype.view.OutputView;

/**
 * 
 * An {@code OutputController} handles events coming from
 * {@link net.sf.mvc.prototype.model.Model Model} and passes them on to
 * {@link net.sf.mvc.prototype.view.OutputView OutputView}.
 * 
 * @author <a href="mailto:alex.kerner.24@googlemail.com">Alexander Kerner</a>
 * @version 2010-11-02
 * 
 * @param <V>
 *            type of {@link net.sf.mvc.prototype.view.OutputView OutputView}
 */
public interface OutputController<V extends OutputView> extends Controller {

	/**
	 * 
	 * Add an {@link net.sf.mvc.prototype.view.OutputView OutputView} to this
	 * {@code OutputController}. All events coming from this
	 * {@code OutputController}'s {@link net.sf.mvc.prototype.model.Model Model}
	 * will be send to all {@link net.sf.mvc.prototype.view.OutputView
	 * OutputView}s that are registered to this {@code OutputController}.
	 * 
	 * @param view
	 *            {@link net.sf.mvc.prototype.view.OutputView OutputView} that
	 *            is added to this {@code OutputController}
	 */
	void addViewOut(V view);

	/**
	 * 
	 * Remove an {@link net.sf.mvc.prototype.view.OutputView OutputView} from
	 * this {@code OutputController}. All events coming from this
	 * {@code OutputController}'s {@link net.sf.mvc.prototype.model.Model Model}
	 * will not anymore send to this
	 * {@link net.sf.mvc.prototype.view.OutputView OutputView}.
	 * 
	 * @param view
	 *            {@link net.sf.mvc.prototype.view.OutputView OutputView} that
	 *            is removed from this {@code OutputController}
	 */
	void removeViewOut(V view);

	/**
	 * 
	 * Send an info message to all views.
	 * 
	 * @param msg
	 *            the message
	 */
	void infoMsg(String msg);

	/**
	 * 
	 * Send an warning message to all views.
	 * 
	 * @param msg
	 *            the message
	 */
	void warnMsg(String msg);

	/**
	 * 
	 * Send an error message to all views.
	 * 
	 * @param msg
	 *            the message
	 */
	void errorMsg(String msg);

	/**
	 * 
	 * Shutdown the application.
	 * 
	 */
	void shutdown();

}
