/**********************************************************************
Copyright (c) 2010 Alexander Kerner. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 ***********************************************************************/

package net.sf.mvc.prototype.view;

import java.util.ArrayList;
import java.util.Collection;

import net.sf.mvc.prototype.controller.InputController;
import net.sf.mvc.prototype.controller.OutputController;
import net.sf.mvc.prototype.model.Model;

/**
 * 
 * {@code AbstractInputView} is a prototype implementation for {@link InputView}
 * .
 * 
 * @author <a href="mailto:alex.kerner.24@googlemail.com">Alexander Kerner</a>
 * @version 2010-11-01
 * 
 * @param <D>
 *            type of {@link net.sf.mvc.prototype.controller.InputController
 *            InputController}
 */
public abstract class AbstractInputView<D extends InputController<? extends Model<? extends OutputController<? extends OutputView>>>>
		implements InputView<D> {

	/**
	 * This {@code AbstractInputView}'s
	 * {@link net.sf.mvc.prototype.controller.InputController InputController}s.
	 */
	protected final Collection<D> controllerIn = new ArrayList<D>();

	/**
	 * 
	 */
	public void addControllerIn(D controller) {
		synchronized (controllerIn) {
			controllerIn.add(controller);
		}
	};

	/**
	 * 
	 */
	public void removeControllerIn(D controller) {
		synchronized (controllerIn) {
			controllerIn.remove(controller);
		}
	};

}
