/**********************************************************************
Copyright (c) 2010 Alexander Kerner. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 ***********************************************************************/

package net.sf.mvc.prototype.view;

import net.sf.mvc.prototype.controller.InputController;
import net.sf.mvc.prototype.controller.OutputController;
import net.sf.mvc.prototype.model.Model;

/**
 * 
 * 
 * An {@code InputView} takes input from the user and passes it further to one
 * or more {@link net.sf.mvc.prototype.controller.InputController
 * InputController}.
 * 
 * @author <a href="mailto:alex.kerner.24@googlemail.com">Alexander Kerner</a>
 * @version 2010-10-31
 * @see OutputView
 * @see InputController
 * 
 */
public interface InputView<C extends InputController<? extends Model<? extends OutputController<? extends OutputView>>>>
		extends View {

	/**
	 * 
	 * Add an {@link net.sf.mvc.prototype.controller.InputController
	 * InputController} to this {@code InputView}. Events that are created by
	 * this {@code InputView} are broadcasted to all registered
	 * {@link net.sf.mvc.prototype.controller.InputController InputController}s.
	 * 
	 * @param controller
	 *            {@link net.sf.mvc.prototype.controller.InputController
	 *            InputController} that is added
	 */
	void addControllerIn(C controller);

	/**
	 * 
	 * Remove an {@link net.sf.mvc.prototype.controller.InputController
	 * InputController} from this {@code InputView}. Events that are created by
	 * this {@code InputView} are no longer send to this
	 * {@link net.sf.mvc.prototype.controller.InputController InputController}.
	 * 
	 * @param controller
	 *            {@link net.sf.mvc.prototype.controller.InputController
	 *            InputController} that is removed
	 */
	void removeControllerIn(C controller);

}
